@@ -31,15 +31,12 @@
 
 extern gnb_conf_ext_lite_t gnb_conf_ext_lite;
 
-void show_description();
-
+void show_description(void);
 static void show_useage(int argc,char *argv[]);
-
 int check_listen_string(char *listen_string);
 void gnb_setup_listen_addr_port(char *listen_address6_string, uint16_t *port_ptr, char *sockaddress_string, int addr_type);
 void gnb_setup_es_argv(char *es_argv_string);
 
-
 #define GNB_OPT_INIT                   0x91
 
 #define SET_ADDR_SECURE                (GNB_OPT_INIT + 1)
@@ -121,8 +118,7 @@ int is_verbose   = 0;
 int is_trace     = 0;
 int is_extreme_nat_traversal = 0;
 
-gnb_conf_t* gnb_argv(int argc,char *argv[]){
-
+gnb_conf_t* gnb_argv(int argc,char *argv[]) {
     gnb_conf_t *conf;
     uint16_t port_host;
     char *ctl_block_file = NULL;
@@ -132,17 +128,13 @@ gnb_conf_t* gnb_argv(int argc,char *argv[]){
     conf = malloc( sizeof(gnb_conf_t) );
     memset(conf,0,sizeof(gnb_conf_t));
     memset(&gnb_conf_ext_lite,0,sizeof(gnb_conf_ext_lite_t));
-
     gnb_es_arg_list = gnb_arg_list_init(32);
 
     char listen_sockaddress4_string[GNB_IP4_PORT_STRING_SIZE];
     memset(listen_sockaddress4_string,0,GNB_IP4_PORT_STRING_SIZE);
-
     char listen_sockaddress6_string[GNB_IP6_PORT_STRING_SIZE];
     memset(listen_sockaddress6_string,0,GNB_IP6_PORT_STRING_SIZE);
-
     conf->addr_secure = 1;
-
     conf->activate_tun                  = 1;
     conf->activate_node_worker          = 1;
     conf->activate_index_worker         = 1;
@@ -221,20 +213,15 @@ gnb_conf_t* gnb_argv(int argc,char *argv[]){
     #if defined(__FreeBSD__)
     snprintf(conf->ifname,NAME_MAX,"%s","tun0");
     #endif
-
-
     #if defined(__APPLE__)
     snprintf(conf->ifname,NAME_MAX,"%s","utun1");
     #endif
-
     #if defined(__OpenBSD__)
     snprintf(conf->ifname,NAME_MAX,"%s","tun0");
     #endif
-
     #if defined(__linux__)
     snprintf(conf->ifname,NAME_MAX,"%s","gnb_tun");
     #endif
-
     #if defined(_WIN32)
     snprintf(conf->ifname,NAME_MAX,"%s","gnb_tun");
     conf->if_drv = GNB_IF_DRV_TYPE_TAP_WINDOWS;
@@ -248,7 +235,6 @@ gnb_conf_t* gnb_argv(int argc,char *argv[]){
         #ifdef __UNIX_LIKE_OS__
         snprintf(conf->binary_dir, PATH_MAX, "%s", "/tmp");
         #endif
-
         #ifdef _WIN32
         snprintf(conf->binary_dir, PATH_MAX+NAME_MAX, "%s", "c:\\");
         #endif
@@ -267,7 +253,6 @@ gnb_conf_t* gnb_argv(int argc,char *argv[]){
     #endif
 
     int flag;
-
     struct option long_options[] = {
 
       { "conf",     required_argument, 0, 'c' },
@@ -376,51 +361,37 @@ gnb_conf_t* gnb_argv(int argc,char *argv[]){
     int option_index = 0;
 
     while (1) {
-
         opt = getopt_long(argc, argv, "c:n:a:r:PI:b:l:i:46Edp:e:tqVTh",long_options, &option_index);
-
         if ( -1 == opt ) {
             break;
         }
-
         switch (opt) {
-
         case 'c':
             snprintf(conf->conf_dir, PATH_MAX, "%s", optarg);
             break;
-
         case 'P':
             conf->public_index_service = 1;
             break;
-
         case 'I':
             gnb_conf_ext_lite.index_address_string = optarg;
             break;
-
         case 'a':
             gnb_conf_ext_lite.node_address_string = optarg;
             break;
-
         case 'r':
             gnb_conf_ext_lite.node_route_string = optarg;
             break;
-
         case 'n':
             conf->local_uuid = (gnb_uuid_t)strtoull(optarg, NULL, 10);
             conf->lite_mode = 1;
             break;
-
         case 'i':
-
             #if defined(__linux__) ||  defined(_WIN32)
             snprintf(conf->ifname, 16, "%s", optarg);
             conf->ifname[15] = '\0';
             #endif
-
             break;
-
         case SET_IF_DRV:
-
             if ( !strncmp(optarg, "wintun", sizeof("wintun")-1) ) {
                 conf->if_drv = GNB_IF_DRV_TYPE_TAP_WINTUN;
             } else if ( !strncmp(optarg, "tap-windows", sizeof("tap-windows")-1) ) {
@@ -428,13 +399,9 @@ gnb_conf_t* gnb_argv(int argc,char *argv[]){
             } else {
                 conf->if_drv = GNB_IF_DRV_TYPE_DEFAULT;
             }
-
             break;
-
         case 'l':
-
             ret = check_listen_string(optarg);
-
             if ( 0 == ret ) {
                 port_host = (uint16_t)strtoul(optarg, NULL, 10);
                 snprintf(listen_sockaddress6_string, GNB_IP6_PORT_STRING_SIZE, "[:::%d]",    port_host);
@@ -444,148 +411,109 @@ gnb_conf_t* gnb_argv(int argc,char *argv[]){
             } else if( 6 == ret ) {
                 snprintf(listen_sockaddress6_string, GNB_IP6_PORT_STRING_SIZE, "%s", optarg);
             }
-
             break;
-
         case 'b':
             ctl_block_file = optarg;
             break;
-
         case '4':
             conf->udp_socket_type = GNB_ADDR_TYPE_IPV4;
             break;
-
         case '6':
             conf->udp_socket_type = GNB_ADDR_TYPE_IPV6;
             break;
-
         case 'E':
             is_extreme_nat_traversal = 1;
             break;
-
         case 'd':
             conf->daemon = 1;
             break;
-
         case 'p':
             gnb_build_passcode(conf->crypto_passcode, optarg);
             break;
-
         case 'q':
             conf->quiet = 1;
             break;
-
         case 't':
             is_self_test = 1;
             break;
         case 'V':
             is_verbose = 1;
             break;
-
         case 'T':
             is_trace = 1;
             break;
-
         case SET_SAFE_INDEX:
             conf->safe_index = 1;
-
         case SET_SYSTEMD_DAEMON:
             conf->systemd_daemon = 1;
             break;
-
         case SET_NODE_WORKER_QUEUE:
             conf->node_woker_queue_length = (uint16_t)strtoul(optarg, NULL, 10);
             break;
-
         case SET_INDEX_WORKER_QUEUE:
             conf->index_woker_queue_length = (uint16_t)strtoul(optarg, NULL, 10);
             break;
-
         case SET_INDEX_SERVICE_WORKER_QUEUE:
             conf->index_service_woker_queue_length = (uint16_t)strtoul(optarg, NULL, 10);
             break;
-
         case SET_PORT_DETECT:
-
             num = sscanf(optarg, "%hu,%hu,%hu", &conf->port_detect_range, &conf->port_detect_start, &conf->port_detect_end);
-
             if ( 3 != num ) {
                 conf->port_detect_range = DETECT_PORT_RANGE;
                 conf->port_detect_start = DETECT_PORT_START;
                 conf->port_detect_end   = DETECT_PORT_END;
             }
-
             break;
-
         case SET_DETECT_INTERVAL:
-
             num = sscanf(optarg, "%u,%u", &conf->address_detect_interval_usec, &conf->full_detect_interval_sec);
-
             if ( 2 != num ) {
                 conf->address_detect_interval_usec = GNB_ADDRESS_DETECT_INTERVAL_USEC;
                 conf->full_detect_interval_sec     = GNB_FULL_DETECT_INTERVAL_SEC;
             }
-        
             break;
-
         case SET_MTU:
             conf->mtu = (unsigned int)strtoul(optarg, NULL, 10);
             break;
-
         case SET_LOG_FILE_PATH:
             snprintf(conf->log_path , PATH_MAX, "%s", optarg);
             break;
-
         case SET_LOG_UDP_TYPE:
-
             if ( !strncmp(optarg, "binary", 16) ) {
                 conf->log_udp_type = GNB_LOG_UDP_TYPE_BINARY;
             } else {
                 conf->log_udp_type = GNB_LOG_UDP_TYPE_TEXT;
             }
-
             break;
-
         case SET_CONSOLE_LOG_LEVEL:
             conf->console_log_level = (uint8_t)strtoul(optarg, NULL, 10);
             break;
-
         case SET_FILE_LOG_LEVEL:
             conf->file_log_level    = (uint8_t)strtoul(optarg, NULL, 10);
             break;
-
         case SET_UDP_LOG_LEVEL:
             conf->udp_log_level     = (uint8_t)strtoul(optarg, NULL, 10);
             break;
-
         case SET_CORE_LOG_LEVEL:
             conf->core_log_level    = (uint8_t)strtoul(optarg, NULL, 10);
             break;
-
         case SET_PF_LOG_LEVEL:
             conf->pf_log_level      = (uint8_t)strtoul(optarg, NULL, 10);
             break;
-
         case SET_MAIN_LOG_LEVEL:
             conf->main_log_level    = (uint8_t)strtoul(optarg, NULL, 10);
             break;
-
         case SET_NODE_LOG_LEVEL:
             conf->node_log_level    = (uint8_t)strtoul(optarg, NULL, 10);
             break;
-
         case SET_INDEX_LOG_LEVEL:
             conf->index_log_level   = (uint8_t)strtoul(optarg, NULL, 10);
             break;
-
         case SET_INDEX_SERVICE_LOG_LEVEL:
             conf->index_service_log_level   = (uint8_t)strtoul(optarg, NULL, 10);
             break;
-
         case SET_DETECT_LOG_LEVEL:
             conf->detect_log_level  = (uint8_t)strtoul(optarg, NULL, 10);
             break;
-
         case SET_CRYPTO_TYPE:
             if ( !strncmp(optarg, "none", 16) ) {
                 conf->pf_bits &= ~(GNB_PF_BITS_CRYPTO_XOR | GNB_PF_BITS_CRYPTO_ARC4);
@@ -598,9 +526,7 @@ gnb_conf_t* gnb_argv(int argc,char *argv[]){
                 conf->pf_bits |= GNB_PF_BITS_CRYPTO_XOR;
             }
             break;
-
         case SET_ZIP:
-
             if ( !strncmp(optarg, "auto", sizeof("auto")-1) ) {
                 conf->zip = GNB_ZIP_AUTO;
             } else if ( !strncmp(optarg, "force", sizeof("force")-1) ) {
@@ -608,25 +534,17 @@ gnb_conf_t* gnb_argv(int argc,char *argv[]){
             } else {
                 conf->zip = GNB_ZIP_AUTO;
             }
-
             break;
-
         case SET_ZIP_LEVEL:
-
             conf->zip_level = (int8_t)strtoul(optarg, NULL, 10);
-
             if ( conf->zip_level > 9 ) {
                 conf->zip_level = 9;
             }
-
             if ( conf->zip_level < -1 ) {
                 conf->zip_level = -1;
             }
-
             break;
-
         case SET_MEMORY_SCALE:
-
             if ( !strncmp(optarg, "tiny", 16) ) {
                 conf->memory = GNB_MEMORY_SCALE_TINY;
             } else if ( !strncmp(optarg, "small", 16) ) {
@@ -638,11 +556,8 @@ gnb_conf_t* gnb_argv(int argc,char *argv[]){
             } else {
                 conf->memory = GNB_MEMORY_SCALE_TINY;
             }
-        
             break;
-
         case SET_MULTI_INDEX_TYPE:
-
             if ( !strncmp(optarg, "simple-fault-tolerant", 16) ) {
                 conf->multi_index_type = GNB_MULTI_ADDRESS_TYPE_SIMPLE_FAULT_TOLERANT;
             } else if ( !strncmp(optarg, "simple-load-balance", 16) ) {
@@ -652,11 +567,8 @@ gnb_conf_t* gnb_argv(int argc,char *argv[]){
             } else {
                 conf->multi_index_type = GNB_MULTI_ADDRESS_TYPE_SIMPLE_LOAD_BALANCE;
             }
-
             break;
-
         case SET_MULTI_FORWARD_TYPE:
-
             if ( !strncmp(optarg, "simple-fault-tolerant", sizeof("simple-fault-tolerant")-1) ) {
                 conf->multi_forward_type = GNB_MULTI_ADDRESS_TYPE_SIMPLE_FAULT_TOLERANT;
             } else if ( !strncmp(optarg, "simple-load-balance", sizeof("simple-load-balance")-1) ) {
@@ -664,11 +576,8 @@ gnb_conf_t* gnb_argv(int argc,char *argv[]){
             } else {
                 conf->multi_forward_type = GNB_MULTI_ADDRESS_TYPE_SIMPLE_FAULT_TOLERANT;
             }
-
             break;
-
         case SET_CRYPTO_KEY_UPDATE_INTERVAL:
-
             if ( !strncmp(optarg, "hour", sizeof("hour")-1 ) ) {
                 conf->crypto_key_update_interval  = GNB_CRYPTO_KEY_UPDATE_INTERVAL_HOUR;
             } else if ( !strncmp(optarg, "minute", sizeof("minute")-1) ) {
@@ -678,11 +587,8 @@ gnb_conf_t* gnb_argv(int argc,char *argv[]){
             } else {
                 conf->crypto_key_update_interval = GNB_CRYPTO_KEY_UPDATE_INTERVAL_NONE;
             }
-
             break;
-
         case SET_MULTI_SOCKET:
-
             if ( !strncmp(optarg, "on", 2) ) {
                 conf->multi_socket = 1;
             } else if ( !strncmp(optarg, "off", 3) ) {
@@ -690,17 +596,11 @@ gnb_conf_t* gnb_argv(int argc,char *argv[]){
             } else {
                 conf->multi_socket = 0;
             }
-
             break;
-
         case SET_PF_ROUTE:
-
             snprintf(conf->pf_route, NAME_MAX, "%s", optarg);
-
             break;
-
         case SET_TUN:
-
             if ( !strncmp(optarg, "on", 2) ) {
                 conf->activate_tun  = 1;
             } else if ( !strncmp(optarg, "off", 3) ) {
@@ -708,11 +608,8 @@ gnb_conf_t* gnb_argv(int argc,char *argv[]){
             } else {
                 conf->activate_tun  = 1;
             }
-
             break;
-
         case SET_INDEX_WORKER:
-
             if ( !strncmp(optarg, "on", 2) ) {
                 conf->activate_index_worker = 1;
             } else if ( !strncmp(optarg, "off", 3) ) {
@@ -720,11 +617,8 @@ gnb_conf_t* gnb_argv(int argc,char *argv[]){
             } else {
                 conf->activate_index_worker = 1;
             }
-
             break;
-
         case SET_INDEX_SERVICE_WORKER:
-
             if ( !strncmp(optarg, "on", 2) ) {
                 conf->activate_index_service_worker = 1;
             } else if ( !strncmp(optarg, "off", 3) ) {
@@ -732,11 +626,8 @@ gnb_conf_t* gnb_argv(int argc,char *argv[]){
             } else {
                 conf->activate_index_service_worker = 1;
             }
-
             break;
-
         case SET_DETECT_WORKER:
-
             if ( !strncmp(optarg, "on", 2) ) {
                 conf->activate_detect_worker = 1;
             } else if ( !strncmp(optarg, "off", 3) ) {
@@ -744,17 +635,11 @@ gnb_conf_t* gnb_argv(int argc,char *argv[]){
             } else {
                 conf->activate_detect_worker = 1;
             }
-
             break;
-
         case SET_PF_WORKER_NUM:
-
             conf->pf_worker_num = (unsigned int)strtoul(optarg, NULL, 10);
-
             break;
-
         case SET_UR0:
-
             if ( !strncmp(optarg, "on", 2) ) {
                 conf->universal_relay0 = 1;
             } else if ( !strncmp(optarg, "off", 3) ) {
@@ -762,11 +647,8 @@ gnb_conf_t* gnb_argv(int argc,char *argv[]){
             } else {
                 conf->universal_relay0 = 1;
             }
-
             break;
-
         case SET_UR1:
-
             if ( !strncmp(optarg, "on", 2) ) {
                 conf->universal_relay1 = 1;
             } else if ( !strncmp(optarg, "off", 3) ) {
@@ -774,11 +656,8 @@ gnb_conf_t* gnb_argv(int argc,char *argv[]){
             } else {
                 conf->universal_relay1 = 1;
             }
-
             break;
-
         case 'U':
-
             if ( !strncmp(optarg, "off", sizeof("off")-1) ) {
                 conf->unified_forwarding = GNB_UNIFIED_FORWARDING_OFF;
             } else if ( !strncmp(optarg, "auto", sizeof("auto")-1) ) {
@@ -792,11 +671,8 @@ gnb_conf_t* gnb_argv(int argc,char *argv[]){
             } else {
                 conf->unified_forwarding = GNB_UNIFIED_FORWARDING_AUTO;
             }
-
             break;
-
         case SET_DIRECT_FORWARDING:
-
             if ( !strncmp(optarg, "on", 2) ) {
                 conf->direct_forwarding = 1;
             } else if ( !strncmp(optarg, "off", 3) ) {
@@ -804,11 +680,9 @@ gnb_conf_t* gnb_argv(int argc,char *argv[]){
             } else {
                 conf->direct_forwarding = 1;
             }
-
             break;
 
         case SET_ADDR_SECURE:
-
             if ( !strncmp(optarg, "on", 2) ) {
                 conf->addr_secure = 1;
             } else if ( !strncmp(optarg, "off", 3) ) {
@@ -816,11 +690,8 @@ gnb_conf_t* gnb_argv(int argc,char *argv[]){
             } else {
                 conf->addr_secure = 1;
             }
-
             break;
-
         case SET_IF_DUMP:
-
             if ( !strncmp(optarg, "on", 2) ) {
                 conf->if_dump = 1;
             } else if ( !strncmp(optarg, "off", 3) ) {
@@ -828,25 +699,19 @@ gnb_conf_t* gnb_argv(int argc,char *argv[]){
             } else {
                 conf->if_dump = 0;
             }
-
             break;
-
         case SET_SOCKET_IF_NAME:
             snprintf(conf->socket_ifname, 16, "%s", optarg);
             break;
-
         case SET_PID_FILE:
             snprintf(conf->pid_file, PATH_MAX, "%s", optarg);
             break;
-
         case SET_NODE_CACHE_FILE:
             snprintf(conf->node_cache_file, PATH_MAX, "%s", optarg);
             break;
-
         case 'e':
             gnb_setup_es_argv(optarg);
             break;
-
         case 'h':
             show_useage(argc, argv);
             exit(0);
@@ -854,42 +719,30 @@ gnb_conf_t* gnb_argv(int argc,char *argv[]){
         default:
             break;
         }
-
-
+		
         if ( 0 == opt ) {
-
             switch (flag) {
-
             case SET_LOG_UDP4:
-
                 if ( NULL != optarg ) {
                     snprintf(conf->log_udp_sockaddress4_string, GNB_IP4_PORT_STRING_SIZE, "%s", optarg);
                 } else {
                     snprintf(conf->log_udp_sockaddress4_string, GNB_IP4_PORT_STRING_SIZE, "%s", "127.0.0.1:8666");
                 }
-
                 break;
-
             default:
                 break;
 
             }
-
             continue;
-
         }
-
-
     }
 
-
     if ( is_extreme_nat_traversal ) {
         conf->multi_socket = 1;
         conf->activate_detect_worker = 1;
         conf->multi_index_type = GNB_MULTI_ADDRESS_TYPE_FULL;
         gnb_setup_es_argv("--upnp");
     }
-
     if ( 0 != conf->systemd_daemon ) {
         conf->daemon = 0;
     }
@@ -906,15 +759,11 @@ gnb_conf_t* gnb_argv(int argc,char *argv[]){
     if ( conf->pf_worker_num > 128 ) {
         conf->pf_worker_num = 128;
     }
-
     if ( conf->pf_worker_num > 0 ) {
         conf->unified_forwarding = GNB_UNIFIED_FORWARDING_OFF;
     }
-
     gnb_addr_secure = conf->addr_secure;
-
 	switch (conf->memory) {
-
 	case GNB_MEMORY_SCALE_TINY:
 		conf->payload_block_size = 1024*8;
 		conf->max_heap_fragment  = 1024*8;
@@ -946,90 +795,79 @@ gnb_conf_t* gnb_argv(int argc,char *argv[]){
         conf->udp6_socket_num = 1;
         conf->udp4_socket_num = 5;
     }
-
     if ( conf->node_woker_queue_length < GNB_WORKER_MIN_QUEUE ) {
         conf->node_woker_queue_length = GNB_WORKER_MIN_QUEUE;
     }
-
     if ( conf->node_woker_queue_length > GNB_WORKER_MAX_QUEUE ) {
         conf->node_woker_queue_length = GNB_WORKER_MAX_QUEUE;
     }
-
     if ( conf->index_woker_queue_length < GNB_WORKER_MIN_QUEUE ) {
         conf->index_woker_queue_length = GNB_WORKER_MIN_QUEUE;
     }
-
     if ( conf->index_woker_queue_length > GNB_WORKER_MAX_QUEUE ) {
         conf->index_woker_queue_length = GNB_WORKER_MAX_QUEUE;
     }
-
     if ( conf->index_service_woker_queue_length < GNB_WORKER_MIN_QUEUE ) {
         conf->index_service_woker_queue_length = GNB_WORKER_MIN_QUEUE;
     }
-
     if ( conf->index_service_woker_queue_length > GNB_WORKER_MAX_QUEUE ) {
         conf->index_service_woker_queue_length = GNB_WORKER_MAX_QUEUE;
     }
-
     if ( conf->pf_woker_in_queue_length < GNB_WORKER_MIN_QUEUE ) {
         conf->pf_woker_in_queue_length = GNB_WORKER_MIN_QUEUE;
     }
-
     if ( conf->pf_woker_in_queue_length > GNB_WORKER_MAX_QUEUE ) {
         conf->pf_woker_in_queue_length = GNB_WORKER_MAX_QUEUE;
     }
-
     conf->pf_woker_out_queue_length = conf->pf_woker_in_queue_length;
-
     if ( GNB_ADDR_TYPE_IPV6 == conf->udp_socket_type && conf->mtu < 1280 ) {
         conf->mtu = 1280;
     }
-
     if ( '\0' == conf->pf_route[0] ) {
         snprintf(conf->pf_route, NAME_MAX, "gnb_pf_route");
     }
-
     if ( '\0' != listen_sockaddress6_string[0] ) {
         gnb_setup_listen_addr_port(conf->listen_address6_string, &conf->udp6_ports[0], listen_sockaddress6_string, AF_INET6);
     } else {
         strncpy(conf->listen_address6_string,"::", sizeof("::")-1);
         conf->udp6_ports[0] = 9001;
     }
-
     if ( '\0' != listen_sockaddress4_string[0] ) {
         gnb_setup_listen_addr_port(conf->listen_address4_string, &conf->udp4_ports[0], listen_sockaddress4_string, AF_INET);
     } else {
         strncpy(conf->listen_address4_string,"0.0.0.0", sizeof("0.0.0.0")-1);
         conf->udp4_ports[0] = 9001;
     }
-
     if ( '\0' == conf->conf_dir[0] ) {
-
         if ( 0 == conf->public_index_service && 0 == conf->lite_mode ) {
             show_useage(argc, argv);
             exit(0);
         }
-
     }
-
     if ( 0 == conf->lite_mode && 0==conf->public_index_service ) {
-
-        if ( '\0' == conf->map_file[0] ) {
-            snprintf(conf->map_file, PATH_MAX+NAME_MAX, "%s/%s", conf->conf_dir, "gnb.map");
-        }
-
-        if ( '\0' == conf->pid_file[0] ) {
-            snprintf(conf->pid_file, PATH_MAX+NAME_MAX,"%s/%s", conf->conf_dir, "gnb.pid");
-        }
-
-        if ( '\0' == conf->node_cache_file[0] ) {
-            snprintf(conf->node_cache_file, PATH_MAX+NAME_MAX,"%s/%s", conf->conf_dir, "node_cache.dump");
-        }
-
+		#if defined(GNB_OPENWRT_BUILD)
+		if ( '\0' == conf->map_file[0] ) {
+			snprintf(conf->map_file,        PATH_MAX+NAME_MAX, "/tmp/gnb.%d.map",       conf->udp4_ports[0]);
+		}
+		if ( '\0' == conf->pid_file[0] ) {
+			snprintf(conf->pid_file,        PATH_MAX+NAME_MAX, "/tmp/gnb.%d.pid",       conf->udp4_ports[0]);
+		}
+		if ( '\0' == conf->node_cache_file[0] ) {
+			snprintf(conf->node_cache_file, PATH_MAX+NAME_MAX, "%s/node_cache.%d.dump", conf->binary_dir, conf->udp4_ports[0]);
+		}
+		#else
+		if ( '\0' == conf->map_file[0] ) {
+			snprintf(conf->map_file, PATH_MAX+NAME_MAX, "%s/%s", conf->conf_dir, "gnb.map");
+		}
+		if ( '\0' == conf->pid_file[0] ) {
+			snprintf(conf->pid_file, PATH_MAX+NAME_MAX,"%s/%s", conf->conf_dir, "gnb.pid");
+		}
+		if ( '\0' == conf->node_cache_file[0] ) {
+			snprintf(conf->node_cache_file, PATH_MAX+NAME_MAX,"%s/%s", conf->conf_dir, "node_cache.dump");
+		}
+		#endif
     } else {
-
         conf->conf_dir[0] = '\0';
-
         #ifdef __UNIX_LIKE_OS__
         snprintf(conf->pid_file,        PATH_MAX+NAME_MAX, "/tmp/gnb.%d.pid",       conf->udp4_ports[0]);
         snprintf(conf->map_file,        PATH_MAX+NAME_MAX, "/tmp/gnb.%d.map",       conf->udp4_ports[0]);
@@ -1041,59 +879,42 @@ gnb_conf_t* gnb_argv(int argc,char *argv[]){
         snprintf(conf->pid_file,        PATH_MAX+NAME_MAX, "%s/gnb.%d.pid",         conf->binary_dir, conf->udp4_ports[0]);
         snprintf(conf->node_cache_file, PATH_MAX+NAME_MAX, "%s/node_cache.%d.dump", conf->binary_dir, conf->udp4_ports[0]);
         #endif
-
     }
-
     if ( NULL != ctl_block_file ) {
         snprintf(conf->map_file,        PATH_MAX+NAME_MAX, "%s",       ctl_block_file);
     }
-
     char  resolved_path[PATH_MAX+NAME_MAX];
-
     if ( '\0' != conf->conf_dir[0] && NULL != gnb_realpath(conf->conf_dir,resolved_path) ) {
         strncpy(conf->conf_dir, resolved_path, PATH_MAX);
     }
-
     if ( NULL != gnb_realpath(conf->map_file,resolved_path) ) {
         strncpy(conf->map_file, resolved_path, PATH_MAX);
     }
-
     if ( NULL != gnb_realpath(conf->pid_file,resolved_path) ) {
         strncpy(conf->pid_file, resolved_path, PATH_MAX);
     }
-
     if ( '\0' != conf->node_cache_file[0] && NULL != gnb_realpath(conf->node_cache_file,resolved_path) ) {
         strncpy(conf->node_cache_file, resolved_path, PATH_MAX);
     }
-
     #ifdef __UNIX_LIKE_OS__
     gnb_arg_append(gnb_es_arg_list, "-b");
     gnb_arg_append(gnb_es_arg_list, conf->map_file);
     #endif
-
-
     #ifdef _WIN32
     char gnb_map_path_q[PATH_MAX+NAME_MAX];
     snprintf(gnb_map_path_q,    PATH_MAX+NAME_MAX, "\"%s\"",              conf->map_file);
     gnb_arg_append(gnb_es_arg_list, "-b");
     gnb_arg_append(gnb_es_arg_list, gnb_map_path_q);
     #endif
-
     gnb_arg_append(gnb_es_arg_list, "--if-loop");
-
     if ( 1 == conf->lite_mode ) {
         gnb_arg_append(gnb_es_arg_list, "--upnp");
     }
-
     return conf;
-
 }
 
-
-static void show_useage(int argc,char *argv[]){
-
+static void show_useage(int argc,char *argv[]) {
     show_description();
-
     printf("Usage: %s [-i IFNAME] -c CONFIG_PATH [OPTION]\n", argv[0]);
     printf("Command Summary:\n");
 
@@ -1202,33 +1023,23 @@ static void show_useage(int argc,char *argv[]){
 
     printf("  %s -n 1001 -a \"i/0/$public_index_ip/$port\" --multi-socket=on -p $passcode\n",argv[0]);
     printf("  %s -n 1002 -a \"i/0/$public_index_ip/$port\" --multi-socket=on -p $passcode\n",argv[0]);
-        
-
 }
 
-void gnb_setup_es_argv(char *es_argv_string){
-
+void gnb_setup_es_argv(char *es_argv_string) {
     int num;
     size_t len;
-
     char argv_string0[1024];
     char argv_string1[1024];
-
     len = strlen(es_argv_string);
-
     if ( len >1024 ) {
         return;
     }
-
     num = sscanf(es_argv_string,"%256[^ ] %256s", argv_string0, argv_string1);
-
     if ( 1 == num ) {
         gnb_arg_append(gnb_es_arg_list, argv_string0);
     } else if ( 2 == num ) {
         gnb_arg_append(gnb_es_arg_list, argv_string0);
         gnb_arg_append(gnb_es_arg_list, argv_string1);
     }
-
     return;
-
 }
